require 'notifiable'
require 'aws-sdk-ses'

# https://docs.aws.amazon.com/ses/latest/DeveloperGuide/deliverability-and-ses.html

module Notifiable
  module Email
    module Ses
  		class Sender < Notifiable::NotifierBase
        
        notifier_attribute :access_id, :secret_key
        
  			protected      
  			def enqueue(device, notification)        				
          raise "access_id missing" if @access_id.nil?
          raise "secret_key missing" if @secret_key.nil?

          sender = 'info@futureworkshops.com'
          recipient = device.token
          htmlbody = "<p>#{notification.message}</p>"
          textbody = notification.message
          encoding = 'UTF-8'

          client.send_email(
            destination: {
              to_addresses: [
                recipient
              ]
            },
            message: {
              body: {
                html: {
                  charset: encoding,
                  data: htmlbody
                },
                text: {
                  charset: encoding,
                  data: textbody
                }
              },
              subject: {
                charset: encoding,
                data: notification.title
              }
            },
            source: sender,
          )

          processed(device)
          
        rescue Aws::SES::Errors::ServiceError => error
          processed(device, NotificationStatus::REJECTED_STATUS, nil, error.message)
  			end
        
        private
        def client
          @client ||= Aws::SES::Client.new(region: 'us-east-1', access_key_id: @access_id, secret_access_key: @secret_key)
        end      
  		end
    end
	end
end
